==> jc-1.4.0.tar.gz: gnu/java/security/x509/ext/PolicyConstraint.h <==
// public class gnu.java.security.x509.ext.PolicyConstraint

// class file dependencies
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class a164115fc7a89df gnu_java_security_x509_ext_PolicyConstraint
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_PolicyConstraint_H_
#define _JC_gnu_java_security_x509_ext_PolicyConstraint_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_PolicyConstraint$sub_refs	_jc_gnu_java_security_x509_ext_PolicyConstraint$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_PolicyConstraint$sub_nonrefs	_jc_gnu_java_security_x509_ext_PolicyConstraint$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_PolicyConstraint$refs	_jc_gnu_java_security_x509_ext_PolicyConstraint$refs;
typedef struct _jc_gnu_java_security_x509_ext_PolicyConstraint$nonrefs	_jc_gnu_java_security_x509_ext_PolicyConstraint$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_PolicyConstraint$object	_jc_gnu_java_security_x509_ext_PolicyConstraint$object;

typedef struct _jc_gnu_java_security_x509_ext_PolicyConstraint$fields_struct	_jc_gnu_java_security_x509_ext_PolicyConstraint$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_PolicyConstraint$vmethods	_jc_gnu_java_security_x509_ext_PolicyConstraint$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_PolicyConstraint$vtable	_jc_gnu_java_security_x509_ext_PolicyConstraint$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_PolicyConstraint$vtype	_jc_gnu_java_security_x509_ext_PolicyConstraint$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_PolicyConstraint$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24PolicyConstraint;
};
extern _jc_gnu_java_security_x509_ext_PolicyConstraint$fields_struct _jc_gnu_java_security_x509_ext_PolicyConstraint$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_PolicyConstraint$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_PolicyConstraint$object *, struct _jc_byte_array *);

// Virtual methods
extern jint _jc_gnu_java_security_x509_ext_PolicyConstraint$method$getInhibitPolicyMapping$03aa1b8fb8c8c0b7(_jc_env *, struct _jc_gnu_java_security_x509_ext_PolicyConstraint$object *);
extern jint _jc_gnu_java_security_x509_ext_PolicyConstraint$method$getRequireExplicitPolicy$890ed43119e8c6e1(_jc_env *, struct _jc_gnu_java_security_x509_ext_PolicyConstraint$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_PolicyConstraint$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_PolicyConstraint$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_PolicyConstraint$method_info$getInhibitPolicyMapping$03aa1b8fb8c8c0b7;
extern _jc_method _jc_gnu_java_security_x509_ext_PolicyConstraint$method_info$getRequireExplicitPolicy$890ed43119e8c6e1;
extern _jc_method _jc_gnu_java_security_x509_ext_PolicyConstraint$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_PolicyConstraint$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_PolicyConstraint$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_PolicyConstraint$vmethods {
	jint	(*getInhibitPolicyMapping$03aa1b8fb8c8c0b7)(_jc_env *, struct _jc_gnu_java_security_x509_ext_PolicyConstraint$object *);
	jint	(*getRequireExplicitPolicy$890ed43119e8c6e1)(_jc_env *, struct _jc_gnu_java_security_x509_ext_PolicyConstraint$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_PolicyConstraint$object *);
};

// Vtable
struct _jc_gnu_java_security_x509_ext_PolicyConstraint$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_PolicyConstraint$vmethods	gnu_java_security_x509_ext_PolicyConstraint;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_PolicyConstraint$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_PolicyConstraint$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_PolicyConstraint$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_PolicyConstraint$refs {
    _jc_gnu_java_security_x509_ext_PolicyConstraint$sub_refs	gnu_java_security_x509_ext_PolicyConstraint;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_PolicyConstraint$sub_nonrefs {
	jint	requireExplicitPolicy;
	jint	inhibitPolicyMapping;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_PolicyConstraint$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_PolicyConstraint$sub_nonrefs	gnu_java_security_x509_ext_PolicyConstraint;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_PolicyConstraint$object {
	_jc_gnu_java_security_x509_ext_PolicyConstraint$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_PolicyConstraint$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_PolicyConstraint$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_PolicyConstraint$vtype _jc_gnu_java_security_x509_ext_PolicyConstraint$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_PolicyConstraint, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_PolicyConstraint$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_PolicyConstraint_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/x509/ext/PolicyConstraint.h <==
// public class gnu.java.security.x509.ext.PolicyConstraint

// class file dependencies
// @dep_class 317dae12883b24de gnu_java_security_x509_ext_Extension__24Value
// @dep_class a164115fc7a89df gnu_java_security_x509_ext_PolicyConstraint
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_security_x509_ext_Extension__24Value

#include "gnu/java/security/x509/ext/Extension__24Value.h"

#ifndef _JC_gnu_java_security_x509_ext_PolicyConstraint_H_
#define _JC_gnu_java_security_x509_ext_PolicyConstraint_H_

// Forward structure declarations
struct _jc_gnu_java_security_OID$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_security_x509_ext_PolicyConstraint$sub_refs	_jc_gnu_java_security_x509_ext_PolicyConstraint$sub_refs;
typedef struct _jc_gnu_java_security_x509_ext_PolicyConstraint$sub_nonrefs	_jc_gnu_java_security_x509_ext_PolicyConstraint$sub_nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_PolicyConstraint$refs	_jc_gnu_java_security_x509_ext_PolicyConstraint$refs;
typedef struct _jc_gnu_java_security_x509_ext_PolicyConstraint$nonrefs	_jc_gnu_java_security_x509_ext_PolicyConstraint$nonrefs;
typedef struct _jc_gnu_java_security_x509_ext_PolicyConstraint$object	_jc_gnu_java_security_x509_ext_PolicyConstraint$object;

typedef struct _jc_gnu_java_security_x509_ext_PolicyConstraint$fields_struct	_jc_gnu_java_security_x509_ext_PolicyConstraint$fields_struct;
typedef const struct _jc_gnu_java_security_x509_ext_PolicyConstraint$vmethods	_jc_gnu_java_security_x509_ext_PolicyConstraint$vmethods;
typedef const struct _jc_gnu_java_security_x509_ext_PolicyConstraint$vtable	_jc_gnu_java_security_x509_ext_PolicyConstraint$vtable;
typedef const struct _jc_gnu_java_security_x509_ext_PolicyConstraint$vtype	_jc_gnu_java_security_x509_ext_PolicyConstraint$vtype;

// Class fields structure
struct _jc_gnu_java_security_x509_ext_PolicyConstraint$fields_struct {
	struct _jc_gnu_java_security_OID$object	*ID;
	struct _jc_java_lang_Class$object	*class__24gnu__24java__24security__24x509__24ext__24PolicyConstraint;
};
extern _jc_gnu_java_security_x509_ext_PolicyConstraint$fields_struct _jc_gnu_java_security_x509_ext_PolicyConstraint$class_fields;

// Constructors
extern void _jc_gnu_java_security_x509_ext_PolicyConstraint$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_gnu_java_security_x509_ext_PolicyConstraint$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_gnu_java_security_x509_ext_PolicyConstraint$method$getInhibitPolicyMapping$03aa1b8fb8c8c0b7(_jc_env *, struct _jc_gnu_java_security_x509_ext_PolicyConstraint$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_java_security_x509_ext_PolicyConstraint$method$getRequireExplicitPolicy$890ed43119e8c6e1(_jc_env *, struct _jc_gnu_java_security_x509_ext_PolicyConstraint$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_security_x509_ext_PolicyConstraint$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_gnu_java_security_x509_ext_PolicyConstraint$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_x509_ext_PolicyConstraint$method_info$getInhibitPolicyMapping$03aa1b8fb8c8c0b7;
extern _jc_method _jc_gnu_java_security_x509_ext_PolicyConstraint$method_info$getRequireExplicitPolicy$890ed43119e8c6e1;
extern _jc_method _jc_gnu_java_security_x509_ext_PolicyConstraint$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_gnu_java_security_x509_ext_PolicyConstraint$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_security_x509_ext_PolicyConstraint$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_x509_ext_PolicyConstraint$vmethods {
	jint	(*getInhibitPolicyMapping$03aa1b8fb8c8c0b7)(_jc_env *, struct _jc_gnu_java_security_x509_ext_PolicyConstraint$object *) _JC_JCNI_ATTR;
	jint	(*getRequireExplicitPolicy$890ed43119e8c6e1)(_jc_env *, struct _jc_gnu_java_security_x509_ext_PolicyConstraint$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_gnu_java_security_x509_ext_PolicyConstraint$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_x509_ext_PolicyConstraint$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_security_x509_ext_Extension__24Value$vmethods	gnu_java_security_x509_ext_Extension__24Value;
	_jc_gnu_java_security_x509_ext_PolicyConstraint$vmethods	gnu_java_security_x509_ext_PolicyConstraint;
};

// Vtype
struct _jc_gnu_java_security_x509_ext_PolicyConstraint$vtype {
	_jc_type			type;
	_jc_gnu_java_security_x509_ext_PolicyConstraint$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_PolicyConstraint$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_PolicyConstraint$refs {
    _jc_gnu_java_security_x509_ext_PolicyConstraint$sub_refs	gnu_java_security_x509_ext_PolicyConstraint;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_refs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_x509_ext_PolicyConstraint$sub_nonrefs {
	jint	requireExplicitPolicy;
	jint	inhibitPolicyMapping;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_x509_ext_PolicyConstraint$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_security_x509_ext_Extension__24Value$sub_nonrefs	gnu_java_security_x509_ext_Extension__24Value;
    _jc_gnu_java_security_x509_ext_PolicyConstraint$sub_nonrefs	gnu_java_security_x509_ext_PolicyConstraint;
};

// Object instance structure
struct _jc_gnu_java_security_x509_ext_PolicyConstraint$object {
	_jc_gnu_java_security_x509_ext_PolicyConstraint$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_x509_ext_PolicyConstraint$vtype	*vtype;
	_jc_gnu_java_security_x509_ext_PolicyConstraint$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_x509_ext_PolicyConstraint$vtype _jc_gnu_java_security_x509_ext_PolicyConstraint$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_x509_ext_PolicyConstraint, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_x509_ext_PolicyConstraint$class_object;

#endif	/* _JC_gnu_java_security_x509_ext_PolicyConstraint_H_ */
